===============================
WikipediaBase
===============================

.. image:: https://badge.fury.io/py/wikipediabase.png
    :target: http://badge.fury.io/py/wikipediabase
    
.. image:: https://travis-ci.org/fakedrake/wikipediabase.png?branch=master
        :target: https://travis-ci.org/fakedrake/wikipediabase

.. image:: https://pypip.in/d/wikipediabase/badge.png
        :target: https://crate.io/packages/wikipediabase?version=latest


"Wikipedia scraper done in python for use in start.mit.edu"

* Free software: BSD license
* Documentation: http://wikipediabase.rtfd.org.

Features
--------

* TODO